Hi all !

I made an easy GUI to use PIP, there are some cool functionnalities :

- Type a library name in the field to install it
- Possibility to list librairies
- Possibility to update all your libraries/or one at once
- Possibility to uninstall last installed(e.g if mistake) or from a list of installed libs
- You can listen to music o/ 

-13/11/2023-
I had to list librairies as URLs to be able to get mouse events over them...

Enjoy ;)
contact : fawn06220@gmail.com
